@@ -17,11 +17,9 @@
 
 
 from zope.interface import implements
-from zope.interface import Interface
 from Products.Five.browser import BrowserView
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from zope.app.component.hooks import getSite
-from zope.component import getMultiAdapter
 from zope.component import adapts
 from OFS.interfaces import IObjectManager
 from interfaces import IFolderDelete
@@ -32,6 +30,7 @@ from interfaces import IActionFailure
 from zope.i18nmessageid import MessageFactory
 _ = MessageFactory('plone')
 
+
 class Action(object):
 
     implements(IAction)
@@ -47,7 +46,6 @@ class Action(object):
         return self.view()()
 
 
-
 class ActionSuccess(Action):
     __module__ = __name__
     implements(IActionSuccess)
@@ -60,14 +58,12 @@ class ActionFailure(Action):
     adapts(IObjectManager)
 
 
-
 class ActionCancel(Action):
     __module__ = __name__
     implements(IActionCancel)
     adapts(IObjectManager)
 
 
-
 class FolderDelete(BrowserView):
     __module__ = __name__
     implements(IFolderDelete)
@@ -79,8 +75,27 @@ class FolderDelete(BrowserView):
         self.paths = None
         self.portal = getSite()
         self.utils = self.portal.plone_utils
-        if self.request.form.has_key('paths'):
-            self.paths = self.request.form['paths']
+        self.initializePaths()
+
+    def initializePaths(self):
+        form = self.request.form
+        if 'paths' in form:
+            paths = form['paths']
+            # strip portal path from paths only when called from
+            # folder_contents but not when called by submitting
+            # to itself (confirmation screen)
+            if 'confirm' in form and form['confirm'] == 'confirmed':
+                self.paths = paths
+            else:
+                self.paths = [self.strip_portal_path(path) for path in paths]
+
+    def strip_portal_path(self, path):
+        portal_path = self.portal.getPhysicalPath()
+        path = path.split('/')
+        for id in portal_path:
+            if id == path[0]:
+                path.pop(0)
+        return '/'.join(path)
 
     def action(self):
         """ return name of the view """
@@ -90,25 +105,26 @@ class FolderDelete(BrowserView):
         """ return paths """
         return self.paths
 
-
-
     def __call__(self):
         """ some documentation """
         if (self.paths is None):
             message = _(u'You must select at least one item.')
             self.utils.addPortalMessage(message)
             return IActionFailure(self.context)()
-        if self.request.has_key('form.button.Cancel'):
-            return IActionCancel(self.context)()
-        if (not self.request.has_key('form.button.Delete')):
+        # if not self submitted, return confirmation screen
+        if ('form.button.Delete' not in self.request
+            and 'form.button.Cancel' not in self.request):
             return self.delete_confirmation()
-        else:
+        elif 'form.button.Delete' in self.request:
             return self.delete_folder()
+        elif 'form.button.Cancel' in self.request:
+            return IActionCancel(self.context)()
 
     def delete_folder(self):
         """ delete objects """
         self.request.set('link_integrity_events_to_expect', len(self.paths))
-        (success, failure,) = self.utils.deleteObjectsByPaths(self.paths, REQUEST=self.request)
+        (success, failure,) = self.utils.deleteObjectsByPaths(self.paths,
+            REQUEST=self.request)
         if success:
             self.status = 'success'
             mapping = {u'items': ', '.join(success)}
@@ -116,9 +132,10 @@ class FolderDelete(BrowserView):
             self.utils.addPortalMessage(message)
             view = IActionSuccess(self.context).view()
         if failure:
-            failure_message = ', '.join([ ('%s (%s)' % (x,
-                                                        str(y))) for (x, y,) in failure.items() ])
-            message = _(u'${items} could not be deleted.', mapping={u'items': failure_message})
+            failure_message = ', '.join([('%s (%s)' % (x,
+                str(y))) for (x, y,) in failure.items()])
+            message = _(u'${items} could not be deleted.',
+                mapping={u'items': failure_message})
             self.utils.addPortalMessage(message, type='error')
             view = IActionFailure(self.context).view()
         return view()
